///////////////////////////////
// ************************* //
//         EASE MIXIN        //
// ************************* //
///////////////////////////////

@mixin transition($transition) {
  -webkit-transition: $transition;
     -moz-transition: $transition;
      -ms-transition: $transition;
       -o-transition: $transition;
          transition: $transition;
}

@mixin ease($property: all, $time: 200ms) {
  @include transition($property $time cubic-bezier(0.250, 0.250, 0.840, 0.325));
}
