<div class="hub-video">
  <div class="hub-video-container">
    <iframe name="embedded" allowfullscreen webkitallowfullscreen mozallowfullscreen frameborder="no" width="100%" height="auto" scrolling="no" src="{{ video.get_embed_url }}"></iframe>
  </div>
</div>
